<?xml version="1.0" encoding="ISO-8859-1" ?>
<!--
# $Id: bigbrother.xsl,v 1.16 2003/01/30 14:27:15 camille Exp $

# Copyright 2001 MandrakeSoft S.A., tous droits rservs

#- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
# Project         : Mandrake Linux
# Module          : Borges
# File            : bigbrother.xsl
# Author          : Camille Bgnis
# Created On      : Mon May  1 16:25:21 2001
# Copyright       : Camille Bgnis camille@mandrakesoft.com,
#                    MandrakeSoft under the GPL license
#- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

This stylesheets takes master-revisions.xml as input and outputs an 
HTML summary table 

-->


<xsl:stylesheet
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  version="1.1"> 

<xsl:param name="reports-path" select="'.'"/>

<xsl:output method="xml" encoding="ISO-8859-1" indent="yes"/>


<xsl:template match="/">

  <xsl:variable name="langs" select="/*[1]/*[1]/foreignphrase"/>

  <xsl:message>
    ////////////////////////////////////////////////
    lang <xsl:copy-of select="$langs"/>
    ////////////////////////////////////////////////
  </xsl:message>

  <xsl:variable name ="title">
    Detailed report status for <xsl:value-of select="/*[1]/@id"/> Release <xsl:value-of select="//revnumber[1]"/>
  </xsl:variable>

  <html>
    <head>
      <META HTTP-EQUIV="Content-Type" CONTENT="text/html; charset=iso8859-1"/>
      <title><xsl:value-of select="$title"/></title>
    </head>
    <body bgcolor="white" text="black" link="red" vlink="brown" alink="black">
      <center>
      <h1><xsl:value-of select="$title"/></h1>
      <font size="-1">
      <table border="1">
        <tr>
          <th>
            Module name
            <br>(Original author)</br>
          </th>
          <th>
            Module title
          </th>
          <xsl:for-each select="$langs">
            <th>
              <xsl:value-of select="text()"/>
            </th>
          </xsl:for-each>
        </tr>
        <xsl:variable name="lang" select="$langs[1]"/>
        <xsl:apply-templates select="//*[@module][@lang=$lang]"/>
        <xsl:call-template name="totals"/>
      </table>
      </font>
      </center>
    </body>
  </html>
  
</xsl:template>



<!-- Now fill each line with module name and author, module title, module status for each language -->

<xsl:template match="*[@module]">
  <xsl:variable name="module" select="@module"/>
  <xsl:variable name="author" select="../*[@module=$module]/*/revhistory/revision[contains(revremark,'write')]/authorinitials/text()[not(.='tbn')]"/>

  <xsl:variable name="langs" select="/*[1]/*[1]/foreignphrase"/>

  <tr>
    <th>
      <div role="sequence">
        <xsl:attribute name="lang"><xsl:value-of select="@lang"/></xsl:attribute>
        <xsl:value-of select="@module"/>
      </div>
      <xsl:call-template name="author">
        <xsl:with-param name="initials" select="$author"/>
      </xsl:call-template>
    </th>
    <td>
      <xsl:value-of select="title"/>
      <xsl:text> </xsl:text>
    </td>
    <xsl:choose>
      <!-- Is the author known?-->
      <xsl:when 
        test="../*[@module=$module]/*/revhistory/revision[contains(revremark,'write')]/authorinitials[not(text()='tbn')]">
        <!-- Is this lang part of the local langs list ?-->
        <xsl:variable name="langslist">
          <xsl:copy-of select="$langs"/>
        </xsl:variable>
        <xsl:apply-templates select="../*[@module=$module][contains($langslist,@lang)]/*/revhistory">
          <!-- Has the original been pedagogic proofread ?-->
          <xsl:with-param name="pproof">
            <xsl:if test="../*[@module=$module]/*/revhistory/revision[contains(revremark,'pproof')][not(date='YYYY-MM-DD')]">
              OK
            </xsl:if>
          </xsl:with-param>          
        </xsl:apply-templates>
      </xsl:when>
      <xsl:otherwise>
        <xsl:for-each select="$langs">
          <td>
            <b><font color="#FF0000">Author?</font></b>
          </td>
        </xsl:for-each>
      </xsl:otherwise>
    </xsl:choose>
  </tr>
</xsl:template>
  

<!-- If the original author is known, fill all language status cells -->

<xsl:template match="revhistory">
  <xsl:param name="pproof"/>
  <xsl:variable name="lang" select="../../@lang"/>
  <xsl:variable name="module" select="../../@module"/>
  
  <!-- generate an HTML file per module per language with all info in it -->
  <xsl:call-template name="module-index">
  </xsl:call-template>
  
  <td>
    <xsl:choose>
      <!-- Is this module XML Valid? -->
      <xsl:when test="../../@valid='no'">
        <strong><font color="#ff0000">XML NOT VALID</font></strong>
      </xsl:when>
      <!-- Is this module fkd? -->
      <xsl:when test="revision[contains(revremark,'corrupt')]">
        <strong><font color="#990000">INVALID</font></strong>
        <xsl:message>
          <xsl:text>Module: </xsl:text><xsl:value-of select="$module"/><xsl:text> in lang </xsl:text><xsl:value-of select="$lang"/><xsl:text> is invalid!&#10;</xsl:text>
        </xsl:message>
      </xsl:when>
      <!-- Is this module not the original? -->
      <xsl:when test="not(revision[contains(revremark,'write')]) or 
                      revision[contains(revremark,'write')]/authorinitials[text()='tbn']">
        <xsl:choose>
          <!-- Has the original not be pedagogic proofreaded? -->
          <xsl:when test="$pproof=''">
            <a href="{$reports-path}/{$lang}/{$module}-index.html">
              Pending
            </a>
          </xsl:when>
          <xsl:otherwise>
            <xsl:choose>
              <!-- has this module not been translated? -->
              <xsl:when test="revision[contains(revremark,'translate')][date='YYYY-MM-DD']">
                <xsl:attribute name="title">
                  <xsl:value-of select="revision[contains(revremark,'translate')]/authorinitials"/>
                </xsl:attribute>
        <xsl:attribute name="lang"><xsl:value-of select="$lang"/></xsl:attribute>
                <a href="{$reports-path}/{$lang}/{$module}-index.html">
                  <b><font color="#3366FF" role="task">Translating</font></b>
                  <br>
                    <xsl:call-template name="author">
                      <xsl:with-param name="initials" select="revision[contains(revremark,'translate')]/authorinitials"/>
                    </xsl:call-template>
                  </br>
                </a>
              </xsl:when>
              <xsl:otherwise>
                <xsl:call-template name="language-proof"/>
              </xsl:otherwise>
            </xsl:choose>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:when>
      <xsl:otherwise>
        <xsl:choose>
          <!-- is this original not written? -->
          <xsl:when test="revision[contains(revremark,'write')][date='YYYY-MM-DD']">
            <xsl:attribute name="title">
              <xsl:value-of select="revision[contains(revremark,'write')]/authorinitials"/>
            </xsl:attribute>
        <xsl:attribute name="lang"><xsl:value-of select="$lang"/></xsl:attribute>
            <a href="{$reports-path}/{$lang}/{$module}-index.html">
              <b><font color="#3366FF" role="task">Writing</font></b>
              <br>
                <xsl:call-template name="author">
                  <xsl:with-param name="initials" select="revision[contains(revremark,'write')]/authorinitials"/>
                </xsl:call-template>
              </br>
            </a>
          </xsl:when>
          <xsl:otherwise>
            <xsl:choose>
              <!-- Has this original not been tech proofreaded? -->
              <xsl:when test="revision[contains(revremark,'tproof')][date='YYYY-MM-DD']">
                <xsl:attribute name="title">
                  <xsl:value-of select="revision[contains(revremark,'tproof')]/authorinitials"/>
                </xsl:attribute>
        <xsl:attribute name="lang"><xsl:value-of select="$lang"/></xsl:attribute>
                <a href="{$reports-path}/{$lang}/{$module}-index.html">
                  <b><font color="#3366FF" role="task">Tech. Proofreading</font></b>
                  <br>
                    <xsl:call-template name="author">
                      <xsl:with-param name="initials" select="revision[contains(revremark,'tproof')]/authorinitials"/>
                    </xsl:call-template>
                  </br>
                </a>
              </xsl:when>
              <!-- Has this original not been pedagogic proofreaded? -->
              <xsl:when test="$pproof=''">
                <xsl:attribute name="title">
                  <xsl:value-of select="revision[contains(revremark,'pproof')]/authorinitials"/>
                </xsl:attribute>
        <xsl:attribute name="lang"><xsl:value-of select="$lang"/></xsl:attribute>
                <a href="{$reports-path}/{$lang}/{$module}-index.html">
                  <b><font color="#3366FF" role="task">Pedagogic Proofreading</font></b>
                  <br>
                    <xsl:call-template name="author">
                      <xsl:with-param name="initials" select="revision[contains(revremark,'pproof')]/authorinitials"/>
                    </xsl:call-template>
                  </br>
                </a>
              </xsl:when>
              <xsl:otherwise>
                <xsl:call-template name="language-proof"/>
              </xsl:otherwise>
            </xsl:choose>
          </xsl:otherwise>
          
        </xsl:choose>
      </xsl:otherwise>
    </xsl:choose>
    
  </td>
</xsl:template>


<!-- this template is called for translated modules only -->
<xsl:template name="language-proof">
    <xsl:if test="../../@synch='no'">
      <xsl:attribute name="BGCOLOR">#ff6666</xsl:attribute>
    </xsl:if>

  <xsl:variable name="lang" select="../../@lang"/>
  <xsl:variable name="module" select="../../@module"/>

  <xsl:choose>
    <!-- Has this original not been ispell'ed? -->
    <xsl:when test="revision[contains(revremark,'ispell')][date='YYYY-MM-DD']">
      <xsl:attribute name="title">
        <xsl:value-of select="revision[contains(revremark,'ispell')]/authorinitials"/>
      </xsl:attribute>
        <xsl:attribute name="lang"><xsl:value-of select="$lang"/></xsl:attribute>
        <a href="{$reports-path}/{$lang}/{$module}-index.html">
      <b><font color="#3366FF" role="task">ispell'ing</font></b>
      <br>
      <xsl:call-template name="author">
        <xsl:with-param name="initials" select="revision[contains(revremark,'ispell')]/authorinitials"/>
      </xsl:call-template>
      </br>
    </a>
    </xsl:when>
    <!-- Has this module not been language proofreaded? -->
    <xsl:when test="revision[contains(revremark,'lproof')][date='YYYY-MM-DD']">
      <xsl:attribute name="title">
        <xsl:value-of select="revision[contains(revremark,'lproof')]/authorinitials"/>
      </xsl:attribute>
        <xsl:attribute name="lang"><xsl:value-of select="$lang"/></xsl:attribute>
        <a href="{$reports-path}/{$lang}/{$module}-index.html">
      <b><font color="#3366FF" role="task">Lang. Proofreading</font></b>
      <br>
      <xsl:call-template name="author">
        <xsl:with-param name="initials" select="revision[contains(revremark,'lproof')]/authorinitials"/>
      </xsl:call-template>
      </br>
    </a>
    </xsl:when>
    <xsl:otherwise>
      <a href="{$reports-path}/{$lang}/{$module}-index.html">
        <b><font color="#006600">OK</font></b>
      </a>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>


<xsl:template name="author">
  <xsl:param name="initials" select="tbn"/>
  <xsl:choose>
    <xsl:when test="$initials != 'tbn'">
      <xsl:apply-templates select="//*[@id=$initials]"/>
    </xsl:when>
    <xsl:otherwise>
      <font color="#FF0000">(To be named)</font>
    </xsl:otherwise>
  </xsl:choose>


</xsl:template>

<xsl:template match="author|editor">
  (<xsl:apply-templates select="firstname"/>
  <xsl:text> </xsl:text>
  <xsl:apply-templates select="surname"/>)
</xsl:template>


<xsl:template name="module-index">
  <xsl:variable name="lang" select="../../@lang"/>
  <xsl:variable name="module" select="../../@module"/>

  <xsl:document href="{$reports-path}/{$lang}/{$module}-index.html">
    <html>
      <head>
        <META HTTP-EQUIV="Content-Type" CONTENT="text/html; charset=iso8859-1"/>
        <title>
          Stats for <xsl:value-of select="$module"/> in <xsl:value-of select="$lang"/>
        </title>
      </head>
      <body>
        <h1>
          Stats for <xsl:value-of select="$module"/> in <xsl:value-of select="$lang"/>
        </h1>
        <table border="1">
          <tr>
            <th>
              Task
            </th>
            <th>
              Finished on
            </th>
            <th>
              Author
            </th>
          </tr>
          <xsl:apply-templates select="revision"/>
        </table>
        <xsl:if test="../../@synch='no'">
          <a href="{$module}.ids.html">Changes in IDs/revisions</a><br/>
          <a href="{$module}.changes.html">Side by side not synched elements</a>
        </xsl:if>

      </body>
    </html>
    
  </xsl:document>

</xsl:template>



<xsl:template match="revision">
  <tr>
    <td>
      <xsl:value-of select="revremark"/>
    </td>
    <td>
      <xsl:choose>
        <xsl:when test="date='YYYY-MM-DD'">
          Pending
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="date"/>
        </xsl:otherwise>
      </xsl:choose>
    </td>
    <td>
      <xsl:call-template name="author">
        <xsl:with-param name="initials" select="authorinitials"/>
      </xsl:call-template>
    </td>
  </tr>
</xsl:template>

<!-- Calculate percents completed -->

<xsl:template name="totals">
  <tr role="totals">
    <th>Total per language</th>
    <th>Percent completed</th>

    <xsl:variable name="root" select="/"/>

    <xsl:variable name="langs" select="/*[1]/*[1]/foreignphrase"/>
    
    <xsl:for-each select="$langs">

      <xsl:variable name="lang" select="text()"/>


      <th>
        <xsl:attribute name="lang">
          <xsl:value-of select="$lang"/>
        </xsl:attribute>
        <xsl:call-template name="total">
          <xsl:with-param name="lang" select="$lang"/>
          <xsl:with-param name="root" select="$root"/>
        </xsl:call-template>
      </th>
    </xsl:for-each>
  </tr>
  
</xsl:template>

<xsl:template name="total">
  <xsl:param name="lang" select="en"/>
  <xsl:param name="root"/>

  
  <xsl:variable name="total"
    select="format-number((
            count($root//*[@module][@lang=$lang]/*/revhistory/revision[contains(revremark,'write')][not(date='YYYY-MM-DD')]) * 4
            + count($root//*[@module][@lang=$lang]/*/revhistory/revision[contains(revremark,'translate')][not(date='YYYY-MM-DD')]) * 8
            + count($root//*[@module][@lang=$lang]/*/revhistory/revision[contains(revremark,'tproof')][not(date='YYYY-MM-DD')]) * 2
            + count($root//*[@module][@lang=$lang]/*/revhistory/revision[contains(revremark,'pproof')][not(date='YYYY-MM-DD')]) * 2
            + count($root//*[@module][@lang=$lang]/*/revhistory/revision[contains(revremark,'ispell')][not(date='YYYY-MM-DD')])
            + count($root//*[@module][@lang=$lang]/*/revhistory/revision[contains(revremark,'lproof')][not(date='YYYY-MM-DD')])) 
            div count($root//*[@module][@lang=$lang]) * 10,'##.##')"/>
  
  <xsl:message>
    lang: <xsl:value-of select="$lang"/>
    total: <xsl:value-of select="$total"/>
  </xsl:message>

  <xsl:value-of select="$total"/>

</xsl:template>

</xsl:stylesheet>
