<?xml version="1.0" encoding="ISO-8859-1" ?>
<!--
# $Id: templates2revisions.xsl,v 1.9 2003/01/09 22:27:01 camille Exp $

#- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
# Project         : Mandrake Linux
# Module          : Borges
# File            : templates2revisions.xsl
# Author          : Camille Bgnis
# Created On      : Mon May  1 16:25:21 2001
# Copyright       : Camille Bgnis camille@mandrakesoft.com,
#                    MandrakeSoft under the GPL license
#- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

this stylesheets inserts in a spec master file the revision info
corresponding to current release found in each related module, to
create a manual wide revisions file that will be used later for
various tracking purposes

-->

<xsl:stylesheet
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  version="1.0"> 

  <xsl:param name="output" select="revisions.xml."/>
  <xsl:param name="modules-path" select="."/>

  <xsl:param name="conf-file" select="../../conf/repository.xml"/>
  <xsl:param name="release">1.0</xsl:param>

  <xsl:variable name="conf" select="document($conf-file,.)"/>
  <xsl:variable name="langs" select="$conf/configuration/repository/languages/lang"/>


<xsl:output method="xml" encoding="ISO-8859-1"
  doctype-system="/usr/share/sgml/docbook/xml-dtd-4.1.2/docbookx.dtd"
  doctype-public="-//OASIS//DTD DocBook XML V4.1.2//EN"/>
 
<xsl:template match="*|@*|comment()|processing-instruction()|text()">
  <xsl:copy>
    <xsl:apply-templates select="*|@*|comment()|processing-instruction()|text()"/>
  </xsl:copy>
</xsl:template>


<xsl:template match="*[para/@role='module']">
  <xsl:variable name="module" select="para/text()"/>
  <xsl:variable name="root" select="name()"/>
  <xsl:for-each select="$langs">
    <xsl:variable name="lang">
      <xsl:value-of select="text()"/>
    </xsl:variable>
    <xsl:variable name="file">
      <xsl:value-of select="$modules-path"/>/<xsl:value-of select="$lang"/>/<xsl:value-of select="$module"/>.xmla</xsl:variable>
    <xsl:variable name="content" select="document($file)"/>
    <xsl:element name="{$root}">
      <xsl:attribute name="lang">
        <xsl:value-of select="$lang"/>
      </xsl:attribute>
      <xsl:attribute name="module">
        <xsl:value-of select="$module"/>
      </xsl:attribute>
      <!-- Compute number of characters in that module for accounting purposes -->
      <xsl:attribute name="vendor">
        <xsl:value-of select="string-length($content/*)"/>
      </xsl:attribute>
      <xsl:text>
      </xsl:text>
      <!-- Copy the *info element that contains the current revision history -->
      <xsl:variable name="infoElement" select="concat($root,'info')"/>
      <xsl:variable name="revision" select="$content/*/*/revhistory/revision[revnumber[text()=$release]]"/>
      <xsl:element name="{$infoElement}">
        <xsl:element name="revhistory">
          <xsl:choose>
            <xsl:when test="$revision">
              <xsl:copy-of select="$revision"/>
            </xsl:when>
            <!-- If there is no revision the module is corrupt, copy a fake one -->
            <xsl:otherwise>
              <xsl:element name="revision">
                <xsl:element name="revnumber">
                  <xsl:text>0</xsl:text>
                </xsl:element> <!-- revnumber -->
                <xsl:element name="date">
                  <xsl:text>YYYY-MM-DD</xsl:text>
                </xsl:element> <!-- date -->
                <xsl:element name="authorinitials">
                  <xsl:text>tbn</xsl:text>
                </xsl:element> <!-- authorinitials -->
                <xsl:element name="revremark">
                  <xsl:text>corrupt</xsl:text>
                </xsl:element> <!-- revremark -->
              </xsl:element> <!-- revision -->
            </xsl:otherwise>
          </xsl:choose>
        </xsl:element> <!-- revhistory -->
      </xsl:element> <!-- infoElement -->
      <xsl:variable name="title">
        <xsl:choose>
          <xsl:when test="$revision">
            <xsl:value-of select="$content/*/title"/>
          </xsl:when>
          <!-- If there is no revision the module is corrupt, copy a fake one -->
          <xsl:otherwise>
            <xsl:text>*** INVALID MODULE ***</xsl:text>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:variable>
      <xsl:element name="title">
        <xsl:value-of select="$title"/>
      </xsl:element> <!-- title -->
      <xsl:text>
      </xsl:text>
      <!-- I just copy the content to prevent duplicate IDs -->
      <!--      <title><xsl:value-of select="$content/*/title"/></title> -->
      <subtitle>
        Language= <xsl:value-of select="$lang"/>
      </subtitle>
      <xsl:text>
      </xsl:text>
      <para>
        <xsl:value-of select="$module"/>
      </para>
      <xsl:text>
      </xsl:text>
    </xsl:element> <!-- Root -->
    <xsl:text>
    </xsl:text>
  </xsl:for-each>
  
</xsl:template>


</xsl:stylesheet>
