#! /usr/bin/perl -w
#---------------------------------------------------------------
# Project         : Linux-Mandrake
# Module          : bin
# File            : accounting.pl
# Author          : Camille Bgnis
# Created On      : Mon Nov 4 2002
# Copyright       : Camille Bgnis <camille@mandrakesoft.com>,
#                    MandrakeSoft under the GPL license
#---------------------------------------------------------------
# synopsis: accounting.pl repository.xml master-revisions.xml
# This script takes a master revisions document and gives for each 
# participating author the billing information according to its work
# on this document.

use strict;
use XML::LibXML;


my $conf = shift || die "$0: Where's the configuration file?!\n";
my $file = shift || die "$0: What's the file to parse?!\n";

# tasks relative cost

my $parser=XML::LibXML->new();
$parser->expand_entities(0);
$parser->load_ext_dtd(0);

# Parse file
my $tree = $parser->parse_file($conf);
my $root = $tree->getDocumentElement;

my @types=$root->findnodes('//revisions/type');

# get tasks weights
my %weight;
foreach my $type (@types) {
    my $name=$type->findvalue('name');
    $weight{$name}=$type->findvalue('weight');
}

# price per written character
my $price=$root->findvalue('//revisions/cost');

# Parse file
$tree = $parser->parse_file($file);
$root = $tree->getDocumentElement;

# get all initials  getElementsByTagName
my @initials=$root->getElementsByTagName('authorinitials');
# get all modules IDs
my @allmodules=$root->findnodes('//@module');
my @modules;

# get only uniq IDs
foreach (sort @allmodules) {
    my $id=$_->getFirstChild->getData;
#   print "$id\n";
    $modules[$#modules+1]=$id unless (($#modules > -1) and ($id eq $modules[$#modules]));
}


my %total;
my %modulescosts;

# sums all costs for each task per author
foreach my $initial_node (@initials) {
    my $initial=$initial_node->getFirstChild->getData;
    my $revision=$initial_node->parentNode;
    my @date=$revision->getElementsByTagName('date');
    my $date=$date[0]->getFirstChild->getData;
    my @task=$revision->getElementsByTagName('revremark');
    my $task=$task[0]->getFirstChild->getData;
    if (not(($date eq "YYYY-MM-DD") or ($initial eq "tbn")) and ($weight{$task})) {
	my $chars=$revision->parentNode->parentNode->parentNode->getAttribute('vendor');
	my $module=$revision->parentNode->parentNode->parentNode->getAttribute('module');
#	print "$initial\t$task\t$chars\n";
	my $total=$weight{$task}*$chars;
	$total{$initial}+=$total;
	$modulescosts{$module.$initial}=$total;
#	print "$module.$initial:\t$modulescosts{$module.$initial}\n";
    }
}


# Create HTML output

my $doc = XML::LibXML::Document->new();
my $html = $doc->createElement('html');
$doc->setDocumentElement($html);
my $body = $doc->createElement('body');
$html->appendChild($body);
my $table = $doc->createElement('table');
$body->appendChild($table);

# print table header
my $authorsline = $doc->createElement('tr');
$table->appendChild($authorsline);
my $cell = $doc->createElement('td');
my $text = XML::LibXML::Text->new("Module");
$cell->appendChild($text);
$authorsline->appendChild($cell);

foreach my $author (sort keys %total) {
    my $cell = $doc->createElement('td');
    $cell->setAttribute('role','author');
    my $text = XML::LibXML::Text->new($author);
    $cell->appendChild($text);
    $authorsline->appendChild($cell);
#    print "$modulefile\n";
    }

foreach my $module (@modules) {
    my $cost = $doc->createElement('tr');
    $cost->setAttribute('role','cost');
    $table->appendChild($cost);

    my $author = $doc->createElement('td');
    my $text = XML::LibXML::Text->new($module);
    $author->appendChild($text);
    $cost->appendChild($author);

# print per module cost
    foreach my $author (sort keys %total) {
	my $cell = $doc->createElement('td');
	$cell->setAttribute('role',$author);
	my $sum = 0;
	$sum =sprintf("%.0f",$modulescosts{$module.$author}/10*$price) if ($modulescosts{$module.$author});
	my $text = XML::LibXML::Text->new($sum);
	$cell->appendChild($text);
	$cost->appendChild($cell);
#    print "$modulefile\n";
    }

#    print "$author\t$sum\n";
}

# print table footer
my $totalline = $doc->createElement('tr');
$table->appendChild($totalline);
$cell = $doc->createElement('td');
$text = XML::LibXML::Text->new("TOTAL");
$cell->appendChild($text);
$totalline->appendChild($cell);

# print per author total cost
foreach my $author (sort keys %total) {
    my $sum=sprintf("%.0f",$total{$author}/10*$price); 
    my $cell = $doc->createElement('td');
    my $text = XML::LibXML::Text->new($sum);
    $cell->appendChild($text);
    $totalline->appendChild($cell);
#    print "$modulefile\n";
    }


print $doc->toString;
