#! /usr/bin/perl -w
#---------------------------------------------------------------
# Project         : Linux-Mandrake
# Module          : bin
# File            : add-revhistory.pl
# Author          : Camille Bgnis
# Created On      : Sun Nov 25 12:25:21 2001
# Copyright       : Camille Bgnis <camille@mandrakesoft.com>,
#                    MandrakeSoft under the GPL license
#---------------------------------------------------------------
# This script adds a revhistory to root element in an 
# XML file
#---------------------------------------------------------------


use strict;
use XML::Twig;

use POSIX;           # only use POSIX style
use File::Basename;  # package to parse filenames
use Getopt::Long;    # package to handle commandline parameters

umask 0022;

########################################################################
# initialize variables:
my $app = fileparse($0);
my $version = "$app 0.1.0    2001-11-25";
my $verbose = 0;
my ($types, $authors, $lang) = "";
########################################################################
my $usage =<<END_OF_USAGE;
Usage:  $app --help --verbose --version <filename>

Options: 
  --help       - shows this text.
  --verbose    - self explaining.
  --version    - shows version number and exits.
  <filename>   - the XML file to add the revhistory to

END_OF_USAGE

sub parse_command_line {
  my ($opt_help, $opt_verbose, $opt_version);
  my $result = GetOptions(
               'help'        => \$opt_help,
               'version'     => \$opt_version,
               'verbose!'    => \$opt_verbose,
               );


  die "$version\n" if defined $opt_version;

  $verbose  = $opt_verbose if defined $opt_verbose;
}
parse_command_line;
my $filename= $ARGV[0] || die $usage;


my $doc= new XML::Twig( KeepEncoding => 1,
			comments => "keep",
			PrettyPrint => "indented",
			);
$doc->parsefile( $filename);

# check there is no revhistory

if ( ! $doc->root->descendants("revhistory") eq "" ) {
    print "there is already a revision history here... exiting\n";
    exit 0;
}

# get root gi name
my $root=$doc->root->gi();
my $rootinfo=$root.'info';

my $hist= new XML::Twig::Elt('revhistory');
$hist->paste($doc->root->descendants("$rootinfo"));

open(FILE, "> $filename") || die "Cannot write in file: \"$filename\" $!\n";

$doc->print( \*FILE );

close (FILE);
