#! /usr/bin/perl -w
#---------------------------------------------------------------
# Project         : Linux-Mandrake
# Module          : bin
# File            : change_revision.pl
# Author          : Camille Bgnis
# Created On      : Mon Oct 17 12:25:21 2001
# Copyright       : Camille Bgnis <camille@mandrakesoft.com>,
#                    MandrakeSoft under the GPL license
#---------------------------------------------------------------
# This script take as input all information to flag on a revision 
# and do it in the source file
#---------------------------------------------------------------

 
use strict;
use XML::Twig;

my $usage="
Usage:
change_revision.pl <source XML file> <revision_type> <initials> <release#>

";
 
my $filename= $ARGV[0];
my $type= $ARGV[1];
my $initials= $ARGV[2];
my $release= $ARGV[3] || die $usage;
my $wop= $type;
$type=~ s/\..*//;
$wop=~ s/.*\.//;
    
my $doc= new XML::Twig( KeepEncoding => 1,
			comments => "keep",
			PrettyPrint => "indented",
			TwigHandlers => { revision => \&revision } 
			);
$doc->parsefile($filename);


sub revision { 
    my( $twig, $revision)= @_; 
    if ( $revision->first_child('revremark') ) {
    	my $rev=$revision->first_child('revremark')->text;
    	my $rel=$revision->first_child('revnumber')->text;
#	print "rev: $rel; rel: $release";
	if ( $rel eq $release ) {
	    if ( $rev eq $type ) {
		my $date=$revision->first_child('date');
		my $authorinitials=$revision->first_child('authorinitials');
		
		if ($wop eq 'todo') {
		    $date->set_text ("YYYY-MM-DD");
		}
		else {
		    my ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst)=localtime(time);
		    $year += 1900; 
		    $mon += 1; 
		    if ( $mon < 10) { $mon= "0".$mon };
		    if ( $mday < 10) { $mday= "0".$mday };
		    $date->set_text ("$year-$mon-$mday");
		}
		$authorinitials->set_text ($initials);
	    }
# remove unnecessary revisions
#     print "\n$rev: $type\n";
	    if ( ( ( $rev eq 'write' || $rev eq 'tproof' || $rev eq 'pproof' ) 
		   && $type eq 'translate') || ( $rev eq 'translate' && $type eq 'write' ) ) {
#     print "\n$rev: $type : delete!\n ";
		$revision->delete();
	    }
	}
    }
}

#put revhistory only in final file
my $revhistory=$doc->root()->first_child()->first_child('revhistory')->sprint();

# remove comments
$revhistory=~s/<!--.*?-->\s*//sg;

# print $revhistory;

my $content=""; 

open(FILE, "< $filename") || die "unknown file: \"$filename\" $!\n";  

while(<FILE>){ $content.=$_; }
 
close (FILE);

open(FILE, "> $filename") || die "unknown file: \"$filename\" $!\n";  

$content=~ s,<revhistory>.*</revhistory>,$revhistory,s;

print FILE $content;

close (FILE);
