#! /usr/bin/perl -w
#---------------------------------------------------------------
# Project         : Linux-Mandrake
# Module          : bin
# File            : costs.pl
# Author          : Camille Bgnis
# Created On      : Mon Nov 4 2002
# Copyright       : Camille Bgnis <camille@mandrakesoft.com>,
#                    MandrakeSoft under the GPL license
#---------------------------------------------------------------
# synopsis: costs.pl repository.xml costs.xhtml
# This script takes all costs information from all manuals of the
# project and build a summary HTML table.

use strict;
use XML::LibXML;


my $conf = shift || die "$0: Where's the configuration file?!\n";
my $file = shift || die "$0: What's the name of the accounting information files?!\n";

# tasks relative cost

my $parser=XML::LibXML->new();
$parser->expand_entities(0);
$parser->load_ext_dtd(0);

# Parse conf file
my $tree = $parser->parse_file($conf);
my $root = $tree->getDocumentElement;

my @manuals=$root->findnodes('//repository/manuals/manual');
my $project=$root->findvalue('//repository/title');

# print $root->findvalue('//manuals/manual');

# build accounting info hash table
my %costs;
my %manualscosts;
my %manualstotal;
my %authorstotal;
# this hash tracks modules billed not to bill them twice
my %modules;
foreach my $manual (@manuals) {
    my $manualfile=$manual->getFirstChild->getData;
# Parse revision file
    $tree = $parser->parse_file("$manualfile/$file");
    $root = $tree->getDocumentElement;
# get authors list
    my @authors=$root->findnodes('//tr[1]/td[@role="author"]');
    foreach my $costline ($root->findnodes('//tr[@role="cost"]')) {
	my $module=$costline->findvalue('td[1]');
	foreach  (@authors) {
	    my $author=$_->getFirstChild->getData;
# do not bill twice
	    if (not($modules{$author.$module})) {
		my $xpath='td[@role="'.$author.'"]';
		my $cost=$costline->findvalue("$xpath");
		$cost = 0 unless ($cost);
#		print "$author:\t$module\t$cost\n";
		$costs{$author}+=$cost;
		$manualscosts{$manualfile.$author}+=$cost;
		$manualstotal{$manualfile}+=$cost;
		$authorstotal{$author}+=$cost;
		$modules{$author.$module}=1;
	    }
	}
    }
}

####################################################



# Create HTML output

my $doc = XML::LibXML::Document->new();
my $html = $doc->createElement('html');
$doc->setDocumentElement($html);
my $body = $doc->createElement('body');
$html->appendChild($body);

my $cell = $doc->createElement('h1');
my $text = XML::LibXML::Text->new($project);
$cell->appendChild($text);
$body->appendChild($cell);

$cell = $doc->createElement('h2');
$text = XML::LibXML::Text->new("Billing information");
$cell->appendChild($text);
$body->appendChild($cell);

my $table = $doc->createElement('table');
$table->setAttribute('border','1');
$body->appendChild($table);

my $manualsline = $doc->createElement('tr');
$table->appendChild($manualsline);
$cell = $doc->createElement('th');
$text = XML::LibXML::Text->new("Author");
$cell->appendChild($text);
$manualsline->appendChild($cell);

foreach my $manual (@manuals) {
    my $manualfile=$manual->getFirstChild->getData;
    my $cell = $doc->createElement('th');
    my $text = XML::LibXML::Text->new($manualfile);
    $cell->appendChild($text);
    $manualsline->appendChild($cell);
#    print "$manualfile\n";
    }

$cell = $doc->createElement('th');
$text = XML::LibXML::Text->new("TOTAL");
$cell->appendChild($text);
$manualsline->appendChild($cell);

foreach my $author (sort keys %costs) {
    my $authorline = $doc->createElement('tr');
    $table->appendChild($authorline);
    my $cell = $doc->createElement('th');
    my $text = XML::LibXML::Text->new($author);
    $cell->appendChild($text);
    $authorline->appendChild($cell);
    foreach my $manual (@manuals) {
	my $manualfile=$manual->getFirstChild->getData;
	my $cell = $doc->createElement('td');
	my $cost=$manualscosts{$manualfile.$author};
	$cost=0 unless $cost;
	my $text = XML::LibXML::Text->new($cost);
	$cell->appendChild($text);
	$authorline->appendChild($cell);
    }
    $cell = $doc->createElement('th');
    $text = XML::LibXML::Text->new($authorstotal{$author});
    $cell->appendChild($text);
    $authorline->appendChild($cell);
}

# print totals footer
$manualsline = $doc->createElement('tr');
$table->appendChild($manualsline);
$cell = $doc->createElement('th');
$text = XML::LibXML::Text->new("TOTAL");
$cell->appendChild($text);
$manualsline->appendChild($cell);

my $bigtotal=0;
foreach my $manual (@manuals) {
    my $manualfile=$manual->getFirstChild->getData;
    my $cell = $doc->createElement('th');
    my $text = XML::LibXML::Text->new($manualstotal{$manualfile});
    $cell->appendChild($text);
    $manualsline->appendChild($cell);
    $bigtotal+=$manualstotal{$manualfile};
}

$cell = $doc->createElement('th');
$text = XML::LibXML::Text->new("$bigtotal");
$cell->appendChild($text);
$manualsline->appendChild($cell);

print $doc->toString;
