#! /usr/bin/perl -w
#---------------------------------------------------------------
# Project         : Linux-Mandrake
# Module          : bin
# File            : get_DB_deps.pl
# Author          : Camille Bgnis
# Created On      : Fri Nov 08 2002
# Copyright       : Camille Bgnis <camille@mandrakesoft.com>,
#                    MandrakeSoft under the GPL license
#---------------------------------------------------------------
# synopsis: get_DB_deps manual_name /path/to/modules/xx/
# This script extracts from a source master file all required modules
# in language "xx".
# Output the results as a list of absolute file names.

use strict;
use XML::Twig;

my $top= "master.top.xml";

my $manual = shift || die "$0: What's the manual name?!\n";
my $modulespath = shift || die "$0: What's the modules files path?!\n";

# Put in this file index needed
my $indexfile=$manual.".index.dependencies";
open(INDEX, "> $indexfile") || die "Write error: \"$indexfile\" $!\n";  

# parse the master.top.xml to extract modules from it
my $twig= new XML::Twig(
			no_prolog => 1,
			TwigHandlers =>
			{ 'para[@role="module"]' => \&module,
			  'index' => \&index, }
			);
$twig->parsefile($top);
$twig->purge;  
close(INDEX);

# Print out modules files needed
sub module {
    my ( $top, $module)= @_;
    my $modulefile=$modulespath.$module->text.".xml";  
    print $modulefile."\n";
    
}

sub index {
    my ( $top, $index)= @_;
    print INDEX $manual.".index.xml\n";
    
}
