#! /usr/bin/perl -w
#---------------------------------------------------------------
# Project         : Linux-Mandrake
# Module          : bin
# File            : master2master.pl
# Author          : Camille Bgnis
# Created On      : Mon Jun 26 2001
# Copyright       : Camille Bgnis <camille@mandrakesoft.com>,
#                    MandrakeSoft under the GPL license
#---------------------------------------------------------------
# synopsis: master2master.pl <tt>
# This script takes a master specs document *.top.xml and replaces
# module elements by apropriate reference entities to those
# modules.

use strict;
use XML::Twig;


my @modules;
my @entities;
my @roots;
my $content="";

my $file = shift || die "$0: What's the file to transform?!\n";

# get modules 
open(FILE, "< $file") || die "unknown file: \"$file\" $!\n";
while(<FILE>){
    s/&/&amp;/g;
    $content.=$_;
}

close (FILE);

# get the doctype as it is not handled by Twig, apparently

$content=~ s/((<\?xml .*?\?>).*<!DOCTYPE.*?)(<\w)/$2$3/s;
my $doctype=$1;

# print "\n##############\n$doctype\n##############\n"; 
# as well as footer comments

my $footer="";
if ( $content=~ s/(.*)(\n<\!--.*)/$1/s ) {
$footer=$2;
}

# print "\n##############\n$footer\n##############\n"; 

# print "\n##############\n$content\n##############\n"; 

my $top= new XML::Twig(
#		       keep_encoding => 1,
		       comments => 'keep',
		       PrettyPrint => 'indented',
		       TwigHandlers =>
		       { 'para[@role="module"]' => \&module,
		         'index' => \&index }
		       );
$top->parse( $content);


for (my $i = 0; $i < $#entities+1; $i++) {

#    print $entities[$i]->text;
#    print $modules[$i]->text."\n";
#    $modules[$i]->parent->suffix($entities[$i]->text);
#    $modules[$i]->cut;
    $entities[$i]->replace($modules[$i]);
}

$content=$top->sprint;
$content=~ s/\&amp;/\&/g;
$content=~ s,</?>\n,,g;
$content=~ s,</?>,,g;
# $content=~ s,.*</bookinfo>,,s;
# $content =~ s,</book>.*,,s;

$content =~ s,<\?.*\?>,$doctype,;
print $content;
print $footer;

sub module
{ my( $top, $module)= @_;
  my $entity = "\n&".$module->text.";\n";
  $entities[$#entities+1] =new XML::Twig::Elt("", $entity);
  $modules[$#modules+1] =$module->parent;
}

sub index
{ my( $top, $module)= @_;
  my $entity = "\n&index;\n";
  $entities[$#entities+1] =new XML::Twig::Elt("", $entity);
  $modules[$#modules+1] =$module;
}
