#!/usr/bin/perl -w

# masterize-module
#
# (C) 2002 by Fabian Mandelbaum <fabman at mandrakesoft dot com> for the
# Borges Project (http://sourceforge.net/projects/borges-dms)
#
# Takes a module and prepares it for single-module compilation
# making a master.top.xml out of the module using the module's root element
# as master.top.xml's root element.
#
# It is ASSUMED that a file named 'entities' exists defining all entities

use strict;
use XML::Twig;

my $dtdPath = $ARGV[2] || '/usr/share/sgml/docbook/xml-dtd-4.1.2/docbookx.dtd';
my $inputFile = $ARGV[0] || 'sample.xml';
my $out = 'master.top.xml'; # = $inputFile;
#$out =~ s/\.xml$/-masterized\.xml/;
my $outputFile = $ARGV[1] || $out;
my $moduleID = $inputFile;
$moduleID =~ s/\.xml(.*)$/-Module/;

my $twig = new XML::Twig ( KeepSpaces => 1,
			   KeepEncoding => 1,
			   NoLWP => 1);

$twig->parsefile($inputFile) || die "ERROR: Cannot parse input file: '$inputFile'.\n";
open(OUTPUT,">$outputFile") || die "ERROR: Cannot open output file: '$outputFile'.\n";
my $documentType = $twig->root->tag; # the root element's name
my @documentContent = $twig->root->children; # rest of the module's content 'as-is'

#output XML header
print OUTPUT "<?xml version=\"", $twig->xml_version, "\" encoding=\"", $twig->encoding, "\"?>\n";

#output DOCTYPE
print OUTPUT "<!DOCTYPE ", $documentType, " SYSTEM \"$dtdPath\" [\n<!ENTITY % entities SYSTEM \"entities\">\n%entities;\n]>\n";

#output content
print OUTPUT "<$documentType id=\"$moduleID\" lang=\"&lang;\">\n";
print OUTPUT "\n<!-- Imported Content BEGINS -->\n";
foreach my $element (@documentContent) {
    print OUTPUT $element->sprint;
}
print OUTPUT "\n<!-- Imported Content ENDS -->\n";
print OUTPUT "</$documentType>\n";

#output footer
print OUTPUT "\n<!-- Keep this comment at the end of the file\nLocal variables:\nmode: xml\nEnd:\n-->\n";

close OUTPUT;

#prints entities
#foreach my $entity ($twig->entity_list) {
#    $entity->print;
#}
