#! /usr/bin/perl -w
#---------------------------------------------------------------
# Project         : Linux-Mandrake
# Module          : bin
# File            : scatter_ids.pl
# Author          : Camille Bgnis
# Created On      : Mon Oct 15 12:25:21 2001
# Copyright       : Camille Bgnis <camille@mandrakesoft.com>,
#                    MandrakeSoft under the GPL license
#---------------------------------------------------------------
# This script assigns automatic IDs to interesting elements in an 
# XML file
# TO BE REWRITTEN
#---------------------------------------------------------------

 
use strict;
use XML::Twig;

# This list can be completed ?


my %element = (
	       "ackno"=> "ak",
	       "address"=> "ad",
	       "alt"=> "al",
	       "arg"=> "ar",
	       "attribution"=> "at",
#	       "authorinitials"=> "ai",
	       "bibliomisc"=> "bc",
	       "bibliomixed"=> "bd",
	       "bibliomset"=> "bt",
	       "bridgehead"=> "bh",
	       "citation"=> "ci",
	       "citetitle"=> "ct",
	       "classsynopsisinfo"=> "cs",
	       "collabname"=> "cn",
	       "confdates"=> "cd",
	       "confnum"=> "cn",
	       "confsponsor"=> "cr",
	       "conftitle"=> "ce",
	       "contractnum"=> "cm",
	       "contractsponsor"=> "cp",
	       "contrib"=> "cb",
	       "copyright"=> "cy",
	       "corpauthor"=> "ca",
	       "corpname"=> "co",
#	       "date"=> "da",
	       "edition"=> "ed",
	       "entry"=> "en",
	       "funcdef"=> "fd",
	       "funcparams"=> "fp",
	       "funcsynopsisinfo"=> "fs",
	       "function"=> "fn",
	       "glossterm"=> "gt",
	       "graphic"=> "gr",
	       "imagedata"=> "im",
	       "indexterm"=> "it",
	       "invpartnumber"=> "in",
	       "isbn"=> "ib",
	       "issn"=> "is",
	       "issuenum"=> "in",
	       "keyword"=> "kw",
	       "label"=> "la",
	       "literallayout"=> "ll",
	       "manvolnum"=> "mv",
	       "member"=> "mm",
	       "modespec"=> "ms",
	       "msgaud"=> "ma",
	       "msglevel"=> "ml",
	       "msgorig"=> "mo",
	       "orgdiv"=> "od",
	       "orgname"=> "on",
	       "othername"=> "ot",
	       "para"=> "pa",
	       "paramdef"=> "pf",
	       "phrase"=> "ph",
	       "productname"=> "pn",
	       "productnumber"=> "pr",
	       "programlisting"=> "pl",
	       "pubdate"=> "pd",
	       "publishername"=> "pu",
	       "pubsnumber"=> "pb",
	       "refclass"=> "rc",
	       "refdescriptor"=> "rd",
	       "refentrytitle"=> "rt",
	       "refname"=> "rn",
	       "refpurpose"=> "rp",
	       "releaseinfo"=> "ri",
	       "remark"=> "re",
	       "screen"=> "sc",
	       "screeninfo"=> "si",
	       "seg"=> "se",
	       "segtitle"=> "st",
	       "seriesvolnums"=> "sv",
	       "shortaffil"=> "sa",
	       "simpara"=> "sp",
	       "subjectterm"=> "su",
	       "subtitle"=> "sb",
	       "synopsis"=> "sy",
	       "term"=> "te",
	       "title"=> "ti",
	       "titleabbrev"=> "ta",
	       "videodata"=> "vd",
	       "volumenum"=> "vn",);

my $usage="
Usage:
scatter_ids.pl <source XML file> [<Root ID>]

";
 
my $filename= $ARGV[0] || die $usage;
 
my $doc= new XML::Twig( 
#                       KeepEncoding => 1,
			comments => "keep",
#			PrettyPrint => "indented",
			);
$doc->parsefile( $filename);

# get root id to prefix all IDs
my $rootid=$doc->root->att("id");

if ( ! $rootid  ) {
    $rootid=$ARGV[1] || die "\nSorry, I need a root ID attribute... Abort.$usage";
    $doc->root->set_att("id",$rootid);

}

# process file

# now I must load the file

my $roottag=$doc->root()->gi();

my $content=""; 

open(FILE, "< $filename") || die "unknown file: \"$filename\" $!\n";  
while(<FILE>){ 
    $content.=$_; 
}
close (FILE);

# Due to Twig messing up with XML formatting, I need to parse the file
# to build a list of elements found with associated id.
# Then reparse the file adding IDs to each element start tag

my $elt_num=0;
my %elements;

# get interesting elements (a hash containing elements and their gi names)

foreach my $tag (keys %element) {
    my $count=0;
    foreach my $single ($doc->get_xpath("//$tag")) {

# Why does the following do not work?
#	my $spec=$single->ancestors("[\@revision]") ? "-1" : "1";
#	print STDERR "$tag $single->gi: $spec\n";

# if they have no ID yet
# and if revision attribute is not "-1" (for itself or any parent (oh no!))
# (which would mean this element is language specific)
	if ( ! ( $single->att("id") || ( $single->att("revision") && 
					 $single->att("revision")==-1 ) || 
		 $single->parent('*[@revision="-1"]') ) ) {
	    my $prefix=$element{$single->gi};
# add one
	    $single->set_att("id",$rootid."-".$prefix.++$count);
#	    print STDERR "\n".$single->att("id")."\n";
	}
    }
}

# $doc->root()->print();

my $root=$doc->root()->sprint();
my $startid;

do {
# Flush possible comment
    $root=~ s/(^[^<]*<!--.*?-->)//s;
    $content=~ s/(^[^<]*<!--.*?-->)//s;
#   print STDERR "\ncomment *********\n $1" if $1;
    print $1 if $1;
# get next start tag
    $root=~ s,^.*?(<\w[^>]*>),,s;
    $startid=$1;
#    print STDERR "\nSTARTID *********\n $startid";
# get everything till next start tag
    $content=~ s,(^.*?)(<\w[^>]*>),,s;
#     print STDERR "\nCHUNK *********\n $1" if $1;
# flush it without start tag
    print $1 if $1;
    my $start=$2;
# and flush the start tag with id if it has one else flush the old one
    if ( $startid) {
	if ( $startid=~/ id\=/ ) { print $startid; } else { print $start; };
    };
} until (! $startid );

print $content;
